Class V1alpha1StorageVersionCondition
java.lang.Object
io.kubernetes.client.openapi.models.V1alpha1StorageVersionCondition
@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen",
date="2026-06-26T22:35:15.319369Z[Etc/UTC]",
comments="Generator version: 7.18.0")
public class V1alpha1StorageVersionCondition
extends Object
Describes the state of the storageVersion at a certain point.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic class -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanCreate an instance of V1alpha1StorageVersionCondition given an JSON stringlastTransitionTime is the last time the condition transitioned from one status to another.message is a human readable string indicating details about the transition.observedGeneration represents the .metadata.generation that the condition was set based upon, if field is set.reason for the condition's last transition.status of the condition, one of True, False, Unknown.getType()type of the condition.inthashCode()lastTransitionTime(OffsetDateTime lastTransitionTime) observedGeneration(Long observedGeneration) voidsetLastTransitionTime(OffsetDateTime lastTransitionTime) voidsetMessage(String message) voidsetObservedGeneration(Long observedGeneration) voidvoidvoidtoJson()Convert an instance of V1alpha1StorageVersionCondition to an JSON stringtoString()static voidvalidateJsonElement(com.google.gson.JsonElement jsonElement) Validates the JSON Element and throws an exception if issues found
-
Field Details
-
SERIALIZED_NAME_LAST_TRANSITION_TIME
- See Also:
-
SERIALIZED_NAME_MESSAGE
- See Also:
-
SERIALIZED_NAME_OBSERVED_GENERATION
- See Also:
-
SERIALIZED_NAME_REASON
- See Also:
-
SERIALIZED_NAME_STATUS
- See Also:
-
SERIALIZED_NAME_TYPE
- See Also:
-
openapiFields
-
openapiRequiredFields
-
-
Constructor Details
-
V1alpha1StorageVersionCondition
public V1alpha1StorageVersionCondition()
-
-
Method Details
-
lastTransitionTime
public V1alpha1StorageVersionCondition lastTransitionTime(@Nullable OffsetDateTime lastTransitionTime) -
getLastTransitionTime
lastTransitionTime is the last time the condition transitioned from one status to another.- Returns:
- lastTransitionTime
-
setLastTransitionTime
-
message
-
getMessage
message is a human readable string indicating details about the transition.- Returns:
- message
-
setMessage
-
observedGeneration
-
getObservedGeneration
observedGeneration represents the .metadata.generation that the condition was set based upon, if field is set.- Returns:
- observedGeneration
-
setObservedGeneration
-
reason
-
getReason
reason for the condition's last transition.- Returns:
- reason
-
setReason
-
status
-
getStatus
status of the condition, one of True, False, Unknown.- Returns:
- status
-
setStatus
-
type
-
getType
type of the condition.- Returns:
- type
-
setType
-
equals
-
hashCode
public int hashCode() -
toString
-
validateJsonElement
Validates the JSON Element and throws an exception if issues found- Parameters:
jsonElement- JSON Element- Throws:
IOException- if the JSON Element is invalid with respect to V1alpha1StorageVersionCondition
-
fromJson
Create an instance of V1alpha1StorageVersionCondition given an JSON string- Parameters:
jsonString- JSON string- Returns:
- An instance of V1alpha1StorageVersionCondition
- Throws:
IOException- if the JSON string is invalid with respect to V1alpha1StorageVersionCondition
-
toJson
Convert an instance of V1alpha1StorageVersionCondition to an JSON string- Returns:
- JSON string
-