Class V1alpha2WorkloadSpec
java.lang.Object
io.kubernetes.client.openapi.models.V1alpha2WorkloadSpec
@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen",
date="2026-06-26T22:35:15.319369Z[Etc/UTC]",
comments="Generator version: 7.18.0")
public class V1alpha2WorkloadSpec
extends Object
WorkloadSpec defines the desired state of a Workload.
-
Nested Class Summary
Nested Classes -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddPodGroupTemplatesItem(V1alpha2PodGroupTemplate podGroupTemplatesItem) controllerRef(V1alpha2TypedLocalObjectReference controllerRef) booleanstatic V1alpha2WorkloadSpecCreate an instance of V1alpha2WorkloadSpec given an JSON stringGet controllerRefPodGroupTemplates is the list of templates that make up the Workload.inthashCode()podGroupTemplates(List<V1alpha2PodGroupTemplate> podGroupTemplates) voidsetControllerRef(V1alpha2TypedLocalObjectReference controllerRef) voidsetPodGroupTemplates(List<V1alpha2PodGroupTemplate> podGroupTemplates) toJson()Convert an instance of V1alpha2WorkloadSpec to an JSON stringtoString()static voidvalidateJsonElement(com.google.gson.JsonElement jsonElement) Validates the JSON Element and throws an exception if issues found
-
Field Details
-
SERIALIZED_NAME_CONTROLLER_REF
- See Also:
-
SERIALIZED_NAME_POD_GROUP_TEMPLATES
- See Also:
-
openapiFields
-
openapiRequiredFields
-
-
Constructor Details
-
V1alpha2WorkloadSpec
public V1alpha2WorkloadSpec()
-
-
Method Details
-
controllerRef
public V1alpha2WorkloadSpec controllerRef(@Nullable V1alpha2TypedLocalObjectReference controllerRef) -
getControllerRef
Get controllerRef- Returns:
- controllerRef
-
setControllerRef
-
podGroupTemplates
public V1alpha2WorkloadSpec podGroupTemplates(@Nonnull List<V1alpha2PodGroupTemplate> podGroupTemplates) -
addPodGroupTemplatesItem
public V1alpha2WorkloadSpec addPodGroupTemplatesItem(V1alpha2PodGroupTemplate podGroupTemplatesItem) -
getPodGroupTemplates
PodGroupTemplates is the list of templates that make up the Workload. The maximum number of templates is 8. This field is immutable.- Returns:
- podGroupTemplates
-
setPodGroupTemplates
-
equals
-
hashCode
public int hashCode() -
toString
-
validateJsonElement
Validates the JSON Element and throws an exception if issues found- Parameters:
jsonElement- JSON Element- Throws:
IOException- if the JSON Element is invalid with respect to V1alpha2WorkloadSpec
-
fromJson
Create an instance of V1alpha2WorkloadSpec given an JSON string- Parameters:
jsonString- JSON string- Returns:
- An instance of V1alpha2WorkloadSpec
- Throws:
IOException- if the JSON string is invalid with respect to V1alpha2WorkloadSpec
-
toJson
Convert an instance of V1alpha2WorkloadSpec to an JSON string- Returns:
- JSON string
-