Class V1alpha3ResourcePoolStatusRequestSpec

java.lang.Object
io.kubernetes.client.openapi.models.V1alpha3ResourcePoolStatusRequestSpec

@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2026-06-26T22:35:15.319369Z[Etc/UTC]", comments="Generator version: 7.18.0") public class V1alpha3ResourcePoolStatusRequestSpec extends Object
ResourcePoolStatusRequestSpec defines the filters for the pool status request.
  • Field Details

  • Constructor Details

    • V1alpha3ResourcePoolStatusRequestSpec

      public V1alpha3ResourcePoolStatusRequestSpec()
  • Method Details

    • driver

      public V1alpha3ResourcePoolStatusRequestSpec driver(@Nonnull String driver)
    • getDriver

      @Nonnull public String getDriver()
      Driver specifies the DRA driver name to filter pools. Only pools from ResourceSlices with this driver will be included. Must be a DNS subdomain (e.g., \"gpu.example.com\").
      Returns:
      driver
    • setDriver

      public void setDriver(@Nonnull String driver)
    • limit

      public V1alpha3ResourcePoolStatusRequestSpec limit(@Nullable Integer limit)
    • getLimit

      @Nullable public Integer getLimit()
      Limit optionally specifies the maximum number of pools to return in the status. If more pools match the filter criteria, the response will be truncated (i.e., len(status.pools) < status.poolCount). Default: 100 Minimum: 1 Maximum: 1000
      Returns:
      limit
    • setLimit

      public void setLimit(@Nullable Integer limit)
    • poolName

      public V1alpha3ResourcePoolStatusRequestSpec poolName(@Nullable String poolName)
    • getPoolName

      @Nullable public String getPoolName()
      PoolName optionally filters to a specific pool name. If not specified, all pools from the specified driver are included. When specified, must be a non-empty valid resource pool name (DNS subdomains separated by \"/\").
      Returns:
      poolName
    • setPoolName

      public void setPoolName(@Nullable String poolName)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • validateJsonElement

      public static void validateJsonElement(com.google.gson.JsonElement jsonElement) throws IOException
      Validates the JSON Element and throws an exception if issues found
      Parameters:
      jsonElement - JSON Element
      Throws:
      IOException - if the JSON Element is invalid with respect to V1alpha3ResourcePoolStatusRequestSpec
    • fromJson

      public static V1alpha3ResourcePoolStatusRequestSpec fromJson(String jsonString) throws IOException
      Create an instance of V1alpha3ResourcePoolStatusRequestSpec given an JSON string
      Parameters:
      jsonString - JSON string
      Returns:
      An instance of V1alpha3ResourcePoolStatusRequestSpec
      Throws:
      IOException - if the JSON string is invalid with respect to V1alpha3ResourcePoolStatusRequestSpec
    • toJson

      public String toJson()
      Convert an instance of V1alpha3ResourcePoolStatusRequestSpec to an JSON string
      Returns:
      JSON string