Class V1alpha3ResourcePoolStatusRequestStatus

java.lang.Object
io.kubernetes.client.openapi.models.V1alpha3ResourcePoolStatusRequestStatus

@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2026-06-26T22:35:15.319369Z[Etc/UTC]", comments="Generator version: 7.18.0") public class V1alpha3ResourcePoolStatusRequestStatus extends Object
ResourcePoolStatusRequestStatus contains the calculated pool status information.
  • Field Details

  • Constructor Details

    • V1alpha3ResourcePoolStatusRequestStatus

      public V1alpha3ResourcePoolStatusRequestStatus()
  • Method Details

    • conditions

      public V1alpha3ResourcePoolStatusRequestStatus conditions(@Nullable List<V1Condition> conditions)
    • addConditionsItem

      public V1alpha3ResourcePoolStatusRequestStatus addConditionsItem(V1Condition conditionsItem)
    • getConditions

      @Nullable public List<V1Condition> getConditions()
      Conditions provide information about the state of the request. A condition with type=Complete or type=Failed will always be set when the status is populated. Known condition types: - \"Complete\": True when the request has been processed successfully - \"Failed\": True when the request could not be processed
      Returns:
      conditions
    • setConditions

      public void setConditions(@Nullable List<V1Condition> conditions)
    • poolCount

      public V1alpha3ResourcePoolStatusRequestStatus poolCount(@Nonnull Integer poolCount)
    • getPoolCount

      @Nonnull public Integer getPoolCount()
      PoolCount is the total number of pools that matched the filter criteria, regardless of truncation. This helps users understand how many pools exist even when the response is truncated. A value of 0 means no pools matched the filter criteria.
      Returns:
      poolCount
    • setPoolCount

      public void setPoolCount(@Nonnull Integer poolCount)
    • pools

    • addPoolsItem

    • getPools

      @Nullable public List<V1alpha3PoolStatus> getPools()
      Pools contains the first `spec.limit` matching pools, sorted by driver then pool name. If `len(pools) < poolCount`, the list was truncated. When omitted, no pools matched the request filters.
      Returns:
      pools
    • setPools

      public void setPools(@Nullable List<V1alpha3PoolStatus> pools)
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • validateJsonElement

      public static void validateJsonElement(com.google.gson.JsonElement jsonElement) throws IOException
      Validates the JSON Element and throws an exception if issues found
      Parameters:
      jsonElement - JSON Element
      Throws:
      IOException - if the JSON Element is invalid with respect to V1alpha3ResourcePoolStatusRequestStatus
    • fromJson

      public static V1alpha3ResourcePoolStatusRequestStatus fromJson(String jsonString) throws IOException
      Create an instance of V1alpha3ResourcePoolStatusRequestStatus given an JSON string
      Parameters:
      jsonString - JSON string
      Returns:
      An instance of V1alpha3ResourcePoolStatusRequestStatus
      Throws:
      IOException - if the JSON string is invalid with respect to V1alpha3ResourcePoolStatusRequestStatus
    • toJson

      public String toJson()
      Convert an instance of V1alpha3ResourcePoolStatusRequestStatus to an JSON string
      Returns:
      JSON string