Class V1alpha3ResourcePoolStatusRequestSpec
java.lang.Object
io.kubernetes.client.openapi.models.V1alpha3ResourcePoolStatusRequestSpec
@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen",
date="2026-06-26T22:35:15.319369Z[Etc/UTC]",
comments="Generator version: 7.18.0")
public class V1alpha3ResourcePoolStatusRequestSpec
extends Object
ResourcePoolStatusRequestSpec defines the filters for the pool status request.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic class -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanCreate an instance of V1alpha3ResourcePoolStatusRequestSpec given an JSON stringDriver specifies the DRA driver name to filter pools.getLimit()Limit optionally specifies the maximum number of pools to return in the status.PoolName optionally filters to a specific pool name.inthashCode()voidvoidvoidsetPoolName(String poolName) toJson()Convert an instance of V1alpha3ResourcePoolStatusRequestSpec to an JSON stringtoString()static voidvalidateJsonElement(com.google.gson.JsonElement jsonElement) Validates the JSON Element and throws an exception if issues found
-
Field Details
-
SERIALIZED_NAME_DRIVER
- See Also:
-
SERIALIZED_NAME_LIMIT
- See Also:
-
SERIALIZED_NAME_POOL_NAME
- See Also:
-
openapiFields
-
openapiRequiredFields
-
-
Constructor Details
-
V1alpha3ResourcePoolStatusRequestSpec
public V1alpha3ResourcePoolStatusRequestSpec()
-
-
Method Details
-
driver
-
getDriver
Driver specifies the DRA driver name to filter pools. Only pools from ResourceSlices with this driver will be included. Must be a DNS subdomain (e.g., \"gpu.example.com\").- Returns:
- driver
-
setDriver
-
limit
-
getLimit
Limit optionally specifies the maximum number of pools to return in the status. If more pools match the filter criteria, the response will be truncated (i.e., len(status.pools) < status.poolCount). Default: 100 Minimum: 1 Maximum: 1000- Returns:
- limit
-
setLimit
-
poolName
-
getPoolName
PoolName optionally filters to a specific pool name. If not specified, all pools from the specified driver are included. When specified, must be a non-empty valid resource pool name (DNS subdomains separated by \"/\").- Returns:
- poolName
-
setPoolName
-
equals
-
hashCode
public int hashCode() -
toString
-
validateJsonElement
Validates the JSON Element and throws an exception if issues found- Parameters:
jsonElement- JSON Element- Throws:
IOException- if the JSON Element is invalid with respect to V1alpha3ResourcePoolStatusRequestSpec
-
fromJson
Create an instance of V1alpha3ResourcePoolStatusRequestSpec given an JSON string- Parameters:
jsonString- JSON string- Returns:
- An instance of V1alpha3ResourcePoolStatusRequestSpec
- Throws:
IOException- if the JSON string is invalid with respect to V1alpha3ResourcePoolStatusRequestSpec
-
toJson
Convert an instance of V1alpha3ResourcePoolStatusRequestSpec to an JSON string- Returns:
- JSON string
-