Class V1alpha3ResourcePoolStatusRequestStatus
java.lang.Object
io.kubernetes.client.openapi.models.V1alpha3ResourcePoolStatusRequestStatus
@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen",
date="2026-06-26T22:35:15.319369Z[Etc/UTC]",
comments="Generator version: 7.18.0")
public class V1alpha3ResourcePoolStatusRequestStatus
extends Object
ResourcePoolStatusRequestStatus contains the calculated pool status information.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic class -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddConditionsItem(V1Condition conditionsItem) addPoolsItem(V1alpha3PoolStatus poolsItem) conditions(List<V1Condition> conditions) booleanCreate an instance of V1alpha3ResourcePoolStatusRequestStatus given an JSON stringConditions provide information about the state of the request.PoolCount is the total number of pools that matched the filter criteria, regardless of truncation.getPools()Pools contains the first `spec.limit` matching pools, sorted by driver then pool name.inthashCode()pools(List<V1alpha3PoolStatus> pools) voidsetConditions(List<V1Condition> conditions) voidsetPoolCount(Integer poolCount) voidsetPools(List<V1alpha3PoolStatus> pools) toJson()Convert an instance of V1alpha3ResourcePoolStatusRequestStatus to an JSON stringtoString()static voidvalidateJsonElement(com.google.gson.JsonElement jsonElement) Validates the JSON Element and throws an exception if issues found
-
Field Details
-
SERIALIZED_NAME_CONDITIONS
- See Also:
-
SERIALIZED_NAME_POOL_COUNT
- See Also:
-
SERIALIZED_NAME_POOLS
- See Also:
-
openapiFields
-
openapiRequiredFields
-
-
Constructor Details
-
V1alpha3ResourcePoolStatusRequestStatus
public V1alpha3ResourcePoolStatusRequestStatus()
-
-
Method Details
-
conditions
-
addConditionsItem
-
getConditions
Conditions provide information about the state of the request. A condition with type=Complete or type=Failed will always be set when the status is populated. Known condition types: - \"Complete\": True when the request has been processed successfully - \"Failed\": True when the request could not be processed- Returns:
- conditions
-
setConditions
-
poolCount
-
getPoolCount
PoolCount is the total number of pools that matched the filter criteria, regardless of truncation. This helps users understand how many pools exist even when the response is truncated. A value of 0 means no pools matched the filter criteria.- Returns:
- poolCount
-
setPoolCount
-
pools
-
addPoolsItem
-
getPools
Pools contains the first `spec.limit` matching pools, sorted by driver then pool name. If `len(pools) < poolCount`, the list was truncated. When omitted, no pools matched the request filters.- Returns:
- pools
-
setPools
-
equals
-
hashCode
public int hashCode() -
toString
-
validateJsonElement
Validates the JSON Element and throws an exception if issues found- Parameters:
jsonElement- JSON Element- Throws:
IOException- if the JSON Element is invalid with respect to V1alpha3ResourcePoolStatusRequestStatus
-
fromJson
public static V1alpha3ResourcePoolStatusRequestStatus fromJson(String jsonString) throws IOException Create an instance of V1alpha3ResourcePoolStatusRequestStatus given an JSON string- Parameters:
jsonString- JSON string- Returns:
- An instance of V1alpha3ResourcePoolStatusRequestStatus
- Throws:
IOException- if the JSON string is invalid with respect to V1alpha3ResourcePoolStatusRequestStatus
-
toJson
Convert an instance of V1alpha3ResourcePoolStatusRequestStatus to an JSON string- Returns:
- JSON string
-